@@ -93,6 +93,19 @@ class BigSortedSet(MutableSet[T], Generic[T]):
     def __enter__(self: Self, /) -> Self:
         return self
 
+    def __eq__(self: Self, other: Any, /) -> bool:
+        if other is self:
+            return True
+        elif isinstance(other, BigSortedSet):
+            return (
+                len(self) == len(other)
+                and all(x == y for x, y in zip(self, other))
+            )
+        elif isinstance(other, AbstractSet):
+            return len(self) == len(other) and other.issuperset(self)
+        else:
+            return NotImplemented
+
     def __exit__(
         self: Self,
         exc_type: Optional[Type[ET]],
@@ -102,21 +115,86 @@ class BigSortedSet(MutableSet[T], Generic[T]):
     ) -> None:
         self.commit()
 
+    def __ge__(self: Self, other: Any, /) -> bool:
+        if isinstance(other, AbstractSet):
+            return self.issuperset(other)
+        else:
+            return NotImplemented
+
     def __getstate__(self: Self, /) -> Path:
         return self._path
 
+    def __gt__(self: Self, other: Any, /) -> bool:
+        if isinstance(other, AbstractSet):
+            return len(self) > len(other) and self.issuperset(other)
+        else:
+            return NotImplemented
+
+    def __iand__(self: Self, other: Iterable[T], /) -> Self:
+        if isinstance(other, Iterable):
+            self.intersection_update(other)
+            return self
+        else:
+            return NotImplemented
+
+    def __ior__(self: Self, other: Iterable[T], /) -> Self:
+        if isinstance(other, Iterable):
+            self.update(other)
+            return self
+        else:
+            return NotImplemented
+
+    def __isub__(self: Self, other: Iterable[T], /) -> Self:
+        if isinstance(other, Iterable):
+            self.difference_update(other)
+            return self
+        else:
+            return NotImplemented
+
     def __iter__(self: Self, /) -> Iterator[T]:
         return chain.from_iterable(
             self._cache_chunk(i)
             for i, _ in enumerate(self._filenames)
         )
 
+    def __ixor__(self: Self, other: Iterable[T], /) -> Self:
+        if isinstance(other, Iterable):
+            self.symmetric_difference_update(other)
+            return self
+        else:
+            return NotImplemented
+
+    def __le__(self: Self, other: Any, /) -> bool:
+        return NotImplemented
+
     def __len__(self: Self, /) -> int:
         return self._len
 
+    def __lt__(self: Self, other: Any, /) -> bool:
+        return NotImplemented
+
+    def __ne__(self: Self, other: Any, /) -> bool:
+        if other is self:
+            return False
+        elif isinstance(other, BigSortedSet):
+            return (
+                len(self) != len(other)
+                or any(x != y for x, y in zip(self, other))
+            )
+        elif isinstance(other, AbstractSet):
+            return len(self) != len(other) or not other.issuperset(self)
+        else:
+            return NotImplemented
+
     def __repr__(self: Self, /) -> str:
         return f"{type(self).__name__}({self._path})"
 
+    def __reversed__(self: Self, /) -> Iterator[T]:
+        return chain.from_iterable(
+            reversed(self._cache_chunk(~i))
+            for i, _ in enumerate(reversed(self._filenames))
+        )
+
     def __setstate__(self: Self, path: Path, /) -> None:
         type(self).__init__(self, path)
 
@@ -290,6 +368,13 @@ class BigSortedSet(MutableSet[T], Generic[T]):
         while len(self._cache) >= 16:
             self._commit_chunk(*self._cache.popitem(last=False))
 
+    @classmethod
+    def _from_iterable(cls: Type[Self], iterable: Iterable[T]) -> Self:
+        raise NotImplementedError(
+            "cannot create big instances, create a destination to save"
+            " into instead."
+        )
+
     def _get_filename(self: Self, /) -> int:
         path = self._path
         with open(path / "sorted_set" / "counter.txt", mode="rb") as file:
@@ -395,14 +480,33 @@ class BigSortedSet(MutableSet[T], Generic[T]):
             self._mins[:] = db._mins[:]
 
     def isdisjoint(self: Self, iterable: Iterable[Any], /) -> bool:
-        if length_hint(iterable) > len(self) and isinstance(iterable, AbstractSet):
-            return any(element in iterable for element in self)
+        if iterable is self:
+            return self._len == 0
+        elif isinstance(iterable, BigSortedSet):
+            return 1 not in (
+                i
+                for _, group in groupby(merge(self, iterable))
+                for i, _ in enumerate(group)
+            )
+        elif length_hint(iterable) > len(self) and isinstance(iterable, AbstractSet):
+            return not any(element in iterable for element in self)
         else:
-            return any(element in self for element in iterable)
+            iterator = iter(iterable)
+            while True:
+                chunk = sorted(islice(iterator, CHUNKSIZE_EXTENDED))
+                if not chunk:
+                    return True
+                elif any(element in self for element in chunk):
+                    return False
 
     def issubset(self: Self, iterable: Iterable[Any], /) -> bool:
         if isinstance(iterable, AbstractSet):
             return iterable >= self
+        try:
+            if len(self) > len(iterable):
+                return False
+        except:
+            pass
         path = self._path
         temp = path / "__temp__"
         with BigSortedSet(temp) as db:
@@ -412,7 +516,18 @@ class BigSortedSet(MutableSet[T], Generic[T]):
         return result
 
     def issuperset(self: Self, iterable: Iterable[Any], /) -> bool:
-        return all(element in self for element in iterable)
+        try:
+            if len(self) < len(iterable):
+                return False
+        except:
+            pass
+        iterator = iter(iterable)
+        while True:
+            chunk = sorted(islice(iterable, CHUNKSIZE_EXTENDED))
+            if not chunk:
+                return True
+            elif not all(element in self for element in chunk):
+                return False
 
     def pop(self: Self, /) -> T:
         if self._len == 0:
@@ -446,27 +561,53 @@ class BigSortedSet(MutableSet[T], Generic[T]):
 
     def update(self: Self, /, *iterables: Iterable[Any]) -> None:
         if self._len == 0:
-            filenames = self._filenames
             iterables = (*map(iter, iterables),)
             # Optimized for not `if not in self:` checks when initially empty.
             iterator = chain.from_iterable(iterables)
-            front = (key for key, _ in groupby(sorted(islice(iterator, CHUNKSIZE_EXTENDED ** 2))))
+            front = (
+                key
+                for key, _ in groupby(sorted(islice(
+                    iterator,
+                    CHUNKSIZE_EXTENDED ** 2,
+                )))
+            )
             while True:
                 chunk = [*islice(front, CHUNKSIZE_EXTENDED)]
                 if not chunk:
                     return
-                filenames.append(self._get_filename())
+                self._filenames.append(self._get_filename())
+                self._commit_chunk(filenames[-1], chunk)
+                self._len += len(chunk)
+                self._lens.append(len(chunk))
+                self._mins.append(chunk[0])
+        elif self._len < CHUNKSIZE_EXTENDED ** 2:
+            iterables = (*map(iter, iterables),)
+            # Optimized for not `if not in self:` checks when initially empty.
+            iterator = chain.from_iterable(iterables)
+            front = [*islice(iterator, CHUNKSIZE_EXTENDED ** 2)]
+            # Manually perform small insertions.
+            if len(front) <= self._len // 8:
+                # Sort to encourage cache efficiency.
+                front.sort()
+                for element, _ in groupby(front):
+                    self.add(element)
+                return
+            # Large insertions are merged with the database and then
+            # bulk sorted.
+            front.extend(self)
+            self.clear()
+            front.sort()
+            while True:
+                chunk = [*islice(front, CHUNKSIZE_EXTENDED)]
+                if not chunk:
+                    return
+                self._filenames.append(self._get_filename())
                 self._commit_chunk(filenames[-1], chunk)
                 self._len += len(chunk)
                 self._lens.append(len(chunk))
                 self._mins.append(chunk[0])
         # Chain iterables and collect only new items.
-        iterator = (
-            element
-            for iterable in iterables
-            for element in iterable
-            if element not in self
-        )
+        iterator = chain.from_iterable(iterables)
         while True:
             has_elements = False
             # Fast cache-efficient insertion by sorting in chunks and
